@@ -8,36 +8,27 @@ from .base import BaseCommand, full_options
 
 
 class RunCommand(BaseCommand):
-    command = 'run'
+    command = "run"
 
     def add_options(self, parser):
+        parser.add_argument("-a", "--app", dest="appname", help="The app to run")
         parser.add_argument(
-            '-a',
-            '--app',
-            dest='appname',
-            help='The app to run'
-        )
-        parser.add_argument(
-            '-u',
-            '--update',
+            "-u",
+            "--update",
             action="store_true",
-            help='Update the app before execution'
+            help="Update the app before execution",
         )
 
     @abstractmethod
     def run_app(self, app: BaseConfig, **options):
-        """
-        Start an application.
+        """Start an application.
 
         :param app: The application to start
         """
         ...
 
     def __call__(
-        self,
-        appname: Optional[str] = None,
-        update: Optional[bool] = False,
-        **options
+        self, appname: Optional[str] = None, update: Optional[bool] = False, **options
     ):
         # Confirm all required tools are available
         self.verify_tools()
@@ -50,15 +41,13 @@ class RunCommand(BaseCommand):
         elif appname:
             try:
                 app = self.apps[appname]
-            except KeyError:
+            except KeyError as e:
                 raise BriefcaseCommandError(
-                    "Project doesn't define an application named '{appname}'".format(
-                        appname=appname
-                    ))
+                    f"Project doesn't define an application named '{appname}'"
+                ) from e
         else:
             raise BriefcaseCommandError(
-                "Project specifies more than one application; "
-                "use --app to specify which one to start."
+                "Project specifies more than one application; use --app to specify which one to start."
             )
 
         template_file = self.bundle_path(app)
