@@ -11,10 +11,10 @@ from .base import BaseCommand
 
 
 class UpgradeCommand(BaseCommand):
-    cmd_line = 'briefcase upgrade'
-    command = 'upgrade'
+    cmd_line = "briefcase upgrade"
+    command = "upgrade"
     output_format = None
-    description = 'Upgrade briefcase-managed tools'
+    description = "Upgrade briefcase-managed tools"
 
     def __init__(self, *args, **options):
         super().__init__(*args, **options)
@@ -24,44 +24,39 @@ class UpgradeCommand(BaseCommand):
     def platform(self):
         """The upgrade command always reports as the local platform."""
         return {
-            'darwin': 'macOS',
-            'linux': 'linux',
-            'win32': 'windows',
+            "darwin": "macOS",
+            "linux": "linux",
+            "win32": "windows",
         }[sys.platform]
 
     def bundle_path(self, app):
-        "A placeholder; Upgrade command doesn't have a bundle path"
+        """A placeholder; Upgrade command doesn't have a bundle path."""
         raise NotImplementedError()
 
     def binary_path(self, app):
-        "A placeholder; Upgrade command doesn't have a binary path"
+        """A placeholder; Upgrade command doesn't have a binary path."""
         raise NotImplementedError()
 
     def distribution_path(self, app, packaging_format):
-        "A placeholder; Upgrade command doesn't have a distribution path"
+        """A placeholder; Upgrade command doesn't have a distribution path."""
         raise NotImplementedError()
 
     def add_options(self, parser):
         parser.add_argument(
-            '-l',
-            '--list',
-            dest='list_tools',
-            action='store_true',
-            help='List the Briefcase-managed tools that are currently installed.'
+            "-l",
+            "--list",
+            dest="list_tools",
+            action="store_true",
+            help="List the Briefcase-managed tools that are currently installed.",
         )
         parser.add_argument(
-            'tool_list',
-            metavar='tool',
-            nargs='*',
-            help='The Briefcase-managed tool to upgrade. If no tool is named, all tools will be upgraded.',
+            "tool_list",
+            metavar="tool",
+            nargs="*",
+            help="The Briefcase-managed tool to upgrade. If no tool is named, all tools will be upgraded.",
         )
 
-    def __call__(
-        self,
-        tool_list: List[str],
-        list_tools=False,
-        **options
-    ):
+    def __call__(self, tool_list: List[str], list_tools=False, **options):
         # Verify all the managed SDKs to see which are present.
         managed_tools = {}
         non_managed_tools = set()
@@ -87,29 +82,23 @@ class UpgradeCommand(BaseCommand):
                 found_tools.append(name)
             elif name not in non_managed_tools:
                 raise BriefcaseCommandError(
-                    "Briefcase doesn't know how to manage the tool '{name}'".format(
-                        name=name
-                    )
+                    f"Briefcase doesn't know how to manage the tool '{name}'"
                 )
 
         if found_tools:
             if list_tools:
-                print("Briefcase is managing the following tools:")
+                self.logger.info("Briefcase is managing the following tools:")
                 for name in found_tools:
-                    print(" - {name}".format(name=name))
+                    self.logger.info(f" - {name}")
             else:
-                print('Briefcase will upgrade the following tools:')
+                self.logger.info("Briefcase will upgrade the following tools:")
                 for name in found_tools:
-                    print(" - {name}".format(name=name))
-                print()
+                    self.logger.info(f" - {name}")
 
                 for name in found_tools:
                     tool = managed_tools[name]
-                    print("[{tool.name}] Upgrading {tool.full_name}...".format(tool=tool))
-                    print()
+                    self.logger.info(f"Upgrading {tool.full_name}...", prefix=tool.name)
                     tool.upgrade()
 
-                print()
-
         else:
-            print("Briefcase is not managing any tools.")
+            self.logger.info("Briefcase is not managing any tools.")
