@@ -8,19 +8,18 @@ from briefcase.exceptions import (
     BriefcaseCommandError,
     MissingToolError,
     NetworkFailure,
-    NonManagedToolError
+    NonManagedToolError,
 )
 
 WIX_DOWNLOAD_URL = "https://github.com/wixtoolset/wix3/releases/download/wix3112rtm/wix311-binaries.zip"
 
 
 class WiX:
-    name = 'wix'
-    full_name = 'WiX'
+    name = "wix"
+    full_name = "WiX"
 
     def __init__(self, command, wix_home=None, bin_install=False):
-        """
-        Create a wrapper around a WiX install.
+        """Create a wrapper around a WiX install.
 
         :param command: The command using the wrapper.
         :param wix_home: The path of the WiX installation.
@@ -32,34 +31,33 @@ class WiX:
         if wix_home:
             self.wix_home = wix_home
         else:
-            self.wix_home = command.tools_path / 'wix'
+            self.wix_home = command.tools_path / "wix"
         self.bin_install = bin_install
 
     @property
     def heat_exe(self):
         if self.bin_install:
-            return self.wix_home / 'heat.exe'
+            return self.wix_home / "heat.exe"
         else:
-            return self.wix_home / 'bin' / 'heat.exe'
+            return self.wix_home / "bin" / "heat.exe"
 
     @property
     def light_exe(self):
         if self.bin_install:
-            return self.wix_home / 'light.exe'
+            return self.wix_home / "light.exe"
         else:
-            return self.wix_home / 'bin' / 'light.exe'
+            return self.wix_home / "bin" / "light.exe"
 
     @property
     def candle_exe(self):
         if self.bin_install:
-            return self.wix_home / 'candle.exe'
+            return self.wix_home / "candle.exe"
         else:
-            return self.wix_home / 'bin' / 'candle.exe'
+            return self.wix_home / "bin" / "candle.exe"
 
     @classmethod
     def verify(cls, command, install=True):
-        """
-        Verify that there is a WiX install available.
+        """Verify that there is a WiX install available.
 
         If the WIX environment variable is set, that location will be checked
         for a valid WiX installation.
@@ -72,10 +70,10 @@ class WiX:
         :returns: A valid WiX SDK wrapper. If WiX is not available, and was
             not installed, raises MissingToolError.
         """
-        if command.host_os != 'Windows':
-            raise BriefcaseCommandError("""
-A Windows MSI installer can only be created on Windows.
-""")
+        if command.host_os != "Windows":
+            raise BriefcaseCommandError(
+                "A Windows MSI installer can only be created on Windows."
+            )
 
         # Look for the WIX environment variable
         wix_env = command.os.environ.get("WIX")
@@ -86,19 +84,25 @@ A Windows MSI installer can only be created on Windows.
             wix = WiX(command=command, wix_home=wix_home)
 
             if not wix.exists():
-                raise BriefcaseCommandError("""
+                raise BriefcaseCommandError(
+                    f"""\
 The WIX environment variable does not point to an install of the
 WiX Toolset. Current value: {wix_home!r}
-""".format(wix_home=wix_home))
+"""
+                )
 
         else:
             wix = WiX(command=command, bin_install=True)
 
             if not wix.exists():
                 if install:
+                    command.logger.info(
+                        "The WiX toolset was not found; downloading and installing...",
+                        prefix=cls.name,
+                    )
                     wix.install()
                 else:
-                    raise MissingToolError('WiX')
+                    raise MissingToolError("WiX")
 
         return wix
 
@@ -121,49 +125,45 @@ WiX Toolset. Current value: {wix_home!r}
             return False
 
     def install(self):
-        """
-        Download and install WiX.
-        """
+        """Download and install WiX."""
         try:
             wix_zip_path = self.command.download_url(
                 url=WIX_DOWNLOAD_URL,
                 download_path=self.command.tools_path,
             )
-        except requests_exceptions.ConnectionError:
-            raise NetworkFailure("download WiX")
+        except requests_exceptions.ConnectionError as e:
+            raise NetworkFailure("download WiX") from e
 
         try:
-            print("Installing WiX...")
-            # TODO: Py3.6 compatibility; os.fsdecode not required in Py3.7
-            self.command.shutil.unpack_archive(
-                os.fsdecode(wix_zip_path),
-                extract_dir=os.fsdecode(self.wix_home)
-            )
-        except (shutil.ReadError, EOFError):
-            raise BriefcaseCommandError("""
+            with self.command.input.wait_bar("Installing WiX..."):
+                # TODO: Py3.6 compatibility; os.fsdecode not required in Py3.7
+                self.command.shutil.unpack_archive(
+                    os.fsdecode(wix_zip_path), extract_dir=os.fsdecode(self.wix_home)
+                )
+        except (shutil.ReadError, EOFError) as e:
+            raise BriefcaseCommandError(
+                f"""\
 Unable to unpack WiX ZIP file. The download may have been
 interrupted or corrupted.
 
-Delete {wix_zip_path} and run briefcase again.""".format(
-                    wix_zip_path=wix_zip_path
-                )
-            )
+Delete {wix_zip_path} and run briefcase again.
+"""
+            ) from e
 
         # Zip file no longer needed once unpacked.
         wix_zip_path.unlink()
 
-    def upgrade(self):
-        """
-        Upgrade an existing WiX install.
-        """
-        if self.managed_install:
-            if self.exists():
-                print("Removing old WiX install...")
-                self.command.shutil.rmtree(self.wix_home)
+    def uninstall(self):
+        """Uninstall WiX."""
+        with self.command.input.wait_bar("Removing old WiX install..."):
+            self.command.shutil.rmtree(self.wix_home)
 
-                self.install()
-                print("...done.")
-            else:
-                raise MissingToolError('WiX')
-        else:
-            raise NonManagedToolError('WiX')
+    def upgrade(self):
+        """Upgrade an existing WiX install."""
+        if not self.managed_install:
+            raise NonManagedToolError("WiX")
+        if not self.exists():
+            raise MissingToolError("WiX")
+
+        self.uninstall()
+        self.install()
