@@ -1,10 +1,10 @@
 import enum
-import json
 import re
 import subprocess
 from pathlib import Path
 
-from briefcase.exceptions import BriefcaseCommandError
+from briefcase.exceptions import BriefcaseCommandError, CommandOutputParseError
+from briefcase.integrations.subprocess import json_parser
 
 
 class DeviceState(enum.Enum):
@@ -15,7 +15,8 @@ class DeviceState(enum.Enum):
 
 
 def verify_command_line_tools_install(command):
-    """Verify that command line developer tools are installed and ready for use.
+    """Verify that command line developer tools are installed and ready for
+    use.
 
     A completely clean machine will have neither Xcode *or* the Command Line
     Tools. However, it's possible to install Xcode and *not* install the command
@@ -55,16 +56,12 @@ def verify_xcode_install(command, min_version=None):
 
 
 def ensure_command_line_tools_are_installed(command):
-    """
-    Determine if the Xcode command line tools are installed.
+    """Determine if the Xcode command line tools are installed.
 
     If they are not installed, an exception is raised; in addition, a OS dialog
     will be displayed prompting the user to install Xcode.
 
     :param command: The command that needs to perform the verification check.
-    :param min_version: The minimum allowed version of Xcode, specified as a
-        tuple of integers (e.g., (11, 2, 1)). Default: ``None``, meaning there
-        is no minimum version.
     """
     # We determine if the command line tools are installed by running:
     #
@@ -79,10 +76,10 @@ def ensure_command_line_tools_are_installed(command):
     # Any other status code is a problem.
     try:
         command.subprocess.check_output(
-            ['xcode-select', '--install'],
-            stderr=subprocess.STDOUT
+            ["xcode-select", "--install"], stderr=subprocess.STDOUT
         )
-        raise BriefcaseCommandError("""
+        raise BriefcaseCommandError(
+            """\
 Xcode command line developer tools are not installed.
 
 You should be shown a dialog prompting you to install Xcode and the
@@ -90,108 +87,106 @@ command line tools. Select "Install" to install the command line developer
 tools.
 
 Re-run Briefcase once that installation is complete.
-""")
+"""
+        )
     except subprocess.CalledProcessError as e:
         if e.returncode != 1:
-            print("""
+            command.logger.warning(
+                """
 *************************************************************************
 ** WARNING: Unable to determine if Xcode is installed                  **
 *************************************************************************
 
-   Briefcase will proceed, assuming everything is OK. If you experience
-   problems, this is almost certainly the cause of those problems.
+    Briefcase will proceed, assuming everything is OK. If you experience
+    problems, this is almost certainly the cause of those problems.
 
-   Please report this as a bug at:
+    Please report this as a bug at:
 
-     https://github.com/beeware/briefcase/issues/new
+       https://github.com/beeware/briefcase/issues/new
 
-   In your report, please including the output from running:
+    In your report, please including the output from running:
 
-     xcode-select --install
+        $ xcode-select --install
 
-   from the command prompt.
+    from the command prompt.
 
 *************************************************************************
-""")
+"""
+            )
 
 
 def ensure_xcode_is_installed(
     command,
-    xcode_location=None,
     min_version=None,
+    xcode_location="/Applications/Xcode.app",
 ):
-    """
-    Determine if Xcode is installed; and if so, that it meets minimum version
-    requirements.
+    """Determine if Xcode is installed; and if so, that it meets minimum
+    version requirements.
 
     Raises an exception if XCode isn't installed, or if the version of Xcode
     that is installed doesn't meet the minimum requirement.
 
     :param command: The command that needs to perform the verification check.
-    :param xcode_location: The location where Xcode should be installed.
-        If not given, the location returned by `xcode-select -p` will be used.
     :param min_version: The minimum allowed version of Xcode, specified as a
         tuple of integers (e.g., (11, 2, 1)). Default: ``None``, meaning there
         is no minimum version.
+    :param xcode_location: The location where we expect to find an Xcode install.
+        Used for testing; defaults to ``/Applications/Xcode.app``.
     """
-    # Try the direct approach. Look for the Xcode folder that is created
-    # when you install from the App store.
-
-    if xcode_location is None:
-
-        try:
-            output = command.subprocess.check_output(
-                ['xcode-select', '-p'],
-                stderr=subprocess.STDOUT,
-                universal_newlines=True
-            )
-            xcode_location = output.strip()
-        except subprocess.CalledProcessError:
-            raise BriefcaseCommandError("""
-Could not find Xcode installation.
+    # Check for *any* version of Xcode tools. xcode-select returns:
+    #  * The path to the currently active Xcode install; or
+    #  * error code 2 - No Xcode installation
+    try:
+        command.subprocess.check_output(
+            ["xcode-select", "-p"],
+            stderr=subprocess.STDOUT,
+        )
+    except subprocess.CalledProcessError as e:
+        raise BriefcaseCommandError(
+            """\
+Could not find an Xcode installation.
 
 To select an existing Xcode installation, run:
 
     $ sudo xcode-select --switch path/to/Xcode.app
 
-or install Xcode from the macOS App Store. Re-run Briefcase afterwards.
-""")
-
-    if not Path(xcode_location).exists():
-        raise BriefcaseCommandError("""
-Xcode is not installed.
-
-You can install Xcode from the macOS App Store.
-
-Re-run Briefcase once that installation is complete.
-""")
+or install Xcode from the macOS App Store. Once you have installed Xcode,
+you can re-run Briefcase.
+"""
+        ) from e
 
     try:
+        # xcodebuild -version returns the version of Xcode that is currently
+        # selected. If the current Xcode is a commandline tools install,
+        # returns an error:
+        #   xcode-select: error: tool 'xcodebuild' requires Xcode, but active
+        #   developer directory '/Library/Developer/CommandLineTools' is a
+        #   command line tools instance
         output = command.subprocess.check_output(
-            ['xcodebuild', '-version'],
+            ["xcodebuild", "-version"],
             stderr=subprocess.STDOUT,
-            universal_newlines=True
         )
 
         if min_version is not None:
-            if output.startswith('Xcode '):
+            # Look for a line in the output that reads "Xcode X.Y.Z"
+            version_lines = [
+                line for line in output.split("\n") if line.startswith("Xcode ")
+            ]
+            if version_lines:
                 try:
-                    # Split content up to the first \n
-                    # then split the content after the first space
+                    # Split the content after the first space
                     # and split that content on the dots.
                     # Append 0's to fill any gaps caused by
                     # version numbers that don't have a minor version.
                     version = tuple(
-                        int(v)
-                        for v in output.split('\n')[0].split(' ')[1].split('.')
+                        int(v) for v in version_lines[0].split(" ")[1].split(".")
                     ) + (0, 0)
 
                     if version < min_version:
+                        min_version = ".".join(str(v) for v in min_version)
+                        version = ".".join(str(v) for v in version)
                         raise BriefcaseCommandError(
-                            "Xcode {min_version} is required; {version} is installed. Please update Xcode.".format(
-                                min_version='.'.join(str(v) for v in min_version),
-                                version='.'.join(str(v) for v in version),
-                            )
+                            f"Xcode {min_version} is required; {version} is installed. Please update Xcode."
                         )
                     else:
                         # Version number is acceptable
@@ -199,34 +194,51 @@ Re-run Briefcase once that installation is complete.
                 except IndexError:
                     pass
 
-            print("""
+            command.logger.warning(
+                """
 *************************************************************************
 ** WARNING: Unable to determine the version of Xcode that is installed **
 *************************************************************************
 
-   Briefcase will proceed, assuming everything is OK. If you experience
-   problems, this is almost certainly the cause of those problems.
+    Briefcase will proceed, assuming everything is OK. If you experience
+    problems, this is almost certainly the cause of those problems.
 
-   Please report this as a bug at:
+    Please report this as a bug at:
 
-     https://github.com/beeware/briefcase/issues/new
+      https://github.com/beeware/briefcase/issues/new
 
-   In your report, please including the output from running:
+    In your report, please including the output from running:
 
-     xcodebuild -version
+        $ xcodebuild -version
 
-   from the command prompt.
+    from the command prompt.
 
 *************************************************************************
-""")
+"""
+            )
 
     except subprocess.CalledProcessError as e:
         if " is a command line tools instance" in e.output:
-            raise BriefcaseCommandError("""
-Xcode may be installed, but the active developer directory is a
-command line tools instance. To make the default Xcode install the
-active developer directory, run:
+            # Commandline tools are currently selected. Look for the existence
+            # of the default folder; if that folder doesn't exist, we can't
+            # conclude that Xcode *isn't* installed.
+            if Path(xcode_location).exists():
+                preamble = """\
+Xcode appears to be installed, but the active developer directory is the Xcode
+command line tools. To make Xcode the active developer directory, run:
+"""
+            else:
+                preamble = """\
+You have the Xcode command line tools installed; however, Briefcase requires
+a full Xcode install. Xcode can be downloaded from the macOS App Store.
 
+Once you have installed Xcode, you can make it the active developer directory
+by running:
+"""
+
+            raise BriefcaseCommandError(
+                preamble
+                + """
     $ sudo xcode-select --switch /Applications/Xcode.app
 
 Or, to use a version of Xcode installed in a non-default location:
@@ -234,10 +246,13 @@ Or, to use a version of Xcode installed in a non-default location:
     $ sudo xcode-select --switch /path/to/Xcode.app
 
 and then re-run Briefcase.
-""")
+"""
+            ) from e
+
         else:
-            raise BriefcaseCommandError("""
-The Xcode install appears to exist, but Briefcase was unable to
+            raise BriefcaseCommandError(
+                """\
+An Xcode install appears to exist, but Briefcase was unable to
 determine the current Xcode version. Running:
 
     $ xcodebuild -version
@@ -246,12 +261,12 @@ should return the current Xcode version, but it raised an error.
 
 You may need to re-install Xcode. Re-run Briefcase once that
 installation is complete.
-""")
+"""
+            ) from e
 
 
 def confirm_xcode_license_accepted(command):
-    """
-    Confirm if the Xcode license has been accepted.
+    """Confirm if the Xcode license has been accepted.
 
     :param command: The command that needs to perform the verification check.
     """
@@ -260,12 +275,12 @@ def confirm_xcode_license_accepted(command):
     # accepted. In this case, we can prompt the user to accept the license.
     try:
         command.subprocess.check_output(
-            ['/usr/bin/clang', '--version'],
-            stderr=subprocess.STDOUT
+            ["/usr/bin/clang", "--version"], stderr=subprocess.STDOUT
         )
     except subprocess.CalledProcessError as e:
         if e.returncode == 69:
-            print("""
+            command.logger.info(
+                """
 Use of Xcode and the iOS developer tools are covered by a license that must be
 accepted before you can use those tools.
 
@@ -278,80 +293,88 @@ at the command line and accepting the license there.
 
 Briefcase will try the command line version of this command now. You will need
 to enter your password (Briefcase will not store this password anywhere).
-""")
+"""
+            )
             try:
                 command.subprocess.run(
-                    ['sudo', 'xcodebuild', '-license'],
+                    ["sudo", "xcodebuild", "-license"],
                     check=True,
                 )
             except subprocess.CalledProcessError as e:
                 # status code 1 - sudo fail
                 # status code 69 - license not accepted.
                 if e.returncode == 1:
-                    raise BriefcaseCommandError("""
+                    raise BriefcaseCommandError(
+                        """\
 Briefcase was unable to run the Xcode licensing tool. This may be because you
 did not enter your password correctly, or because your account does not have
-administrator priviliges on this computer.
+administrator privileges on this computer.
 
 You need to accept the Xcode license before Briefcase can package your app.
-""")
+"""
+                    )
                 elif e.returncode == 69:
-                    raise BriefcaseCommandError("""
+                    raise BriefcaseCommandError(
+                        """\
 Xcode license has not been accepted. Briefcase cannot continue.
 
 You need to accept the Xcode license before Briefcase can package your app.
-""")
+"""
+                    )
                 else:
-                    print("""
+                    command.logger.warning(
+                        """
 *************************************************************************
 ** WARNING: Unable to determine if the Xcode license has been accepted **
 *************************************************************************
 
-   Briefcase will proceed, assuming everything is OK. If you experience
-   problems, this is almost certainly the cause of those problems.
+    Briefcase will proceed, assuming everything is OK. If you experience
+    problems, this is almost certainly the cause of those problems.
 
-   Please report this as a bug at:
+    Please report this as a bug at:
 
-     https://github.com/beeware/briefcase/issues/new
+      https://github.com/beeware/briefcase/issues/new
 
-   In your report, please including the output from running:
+    In your report, please including the output from running:
 
-     sudo xcodebuild -license
+        $ sudo xcodebuild -license
 
-   from the command prompt.
+    from the command prompt.
 
 *************************************************************************
-""")
+"""
+                    )
         else:
-            print("""
+            command.logger.warning(
+                """
 *************************************************************************
 ** WARNING: Unable to determine if the Xcode license has been accepted **
 *************************************************************************
 
-   Briefcase will proceed, assuming everything is OK. If you experience
-   problems, this is almost certainly the cause of those problems.
+    Briefcase will proceed, assuming everything is OK. If you experience
+    problems, this is almost certainly the cause of those problems.
 
-   Please report this as a bug at:
+    Please report this as a bug at:
 
-     https://github.com/beeware/briefcase/issues/new
+      https://github.com/beeware/briefcase/issues/new
 
-   In your report, please including the output from running:
+    In your report, please including the output from running:
 
-     /usr/bin/clang --version
+        $ /usr/bin/clang --version
 
-   from the command prompt.
+    from the command prompt.
 
 *************************************************************************
-""")
+"""
+            )
 
 
 def get_simulators(
     command,
     os_name,
-    simulator_location='/Library/Developer/PrivateFrameworks/CoreSimulator.framework/',
+    simulator_location="/Library/Developer/PrivateFrameworks/CoreSimulator.framework/",
 ):
-    """
-    Obtain the simulators available on this machine.
+    """Obtain the simulators available on this machine.
 
     The return value is a 2 level dictionary. The outer dictionary is
     keyed by OS version; the inner dictionary for each OS version
@@ -368,28 +391,27 @@ def get_simulators(
     # If the simulator frameworks don't exist, they will be downloaded
     # and installed. This should only occur on first execution.
     if not Path(simulator_location).exists():
-        command.input("""
+        command.input(
+            f"""
 It looks like the {os_name} Simulator is not installed. The {os_name} Simulator
-must be installed with administrator priviliges.
+must be installed with administrator privileges.
 
 xcodebuild will prompt you for your admin password so that it can download
 and install the simulator.
 
-Press Return to continue: """.format(os_name=os_name))
+Press Return to continue: """
+        )
 
     try:
-        simctl_data = json.loads(
-            command.subprocess.check_output(
-                ['xcrun', 'simctl', 'list', '-j'],
-                universal_newlines=True
-            )
+        simctl_data = command.subprocess.parse_output(
+            json_parser,
+            ["xcrun", "simctl", "list", "-j"],
         )
 
         os_versions = {
-            runtime['name']: runtime['identifier']
-            for runtime in simctl_data['runtimes']
-            if runtime['name'].startswith('{os_name} '.format(os_name=os_name))
-            and runtime['isAvailable']
+            runtime["name"]: runtime["identifier"]
+            for runtime in simctl_data["runtimes"]
+            if runtime["name"].startswith(f"{os_name} ") and runtime["isAvailable"]
         }
 
         # For some reason, simctl varies the style of key that is used to
@@ -401,96 +423,81 @@ Press Return to continue: """.format(os_name=os_name))
         # neither exist, return an empty list.
         simulators = {
             version: {
-                device['udid']: device['name']
-                for device in simctl_data['devices'].get(
-                    identifier,
-                    simctl_data['devices'].get(version, [])
+                device["udid"]: device["name"]
+                for device in simctl_data["devices"].get(
+                    identifier, simctl_data["devices"].get(version, [])
                 )
-                if device['isAvailable']
+                if device["isAvailable"]
             }
             for version, identifier in os_versions.items()
         }
 
         # Purge any versions with no devices
         versions_with_no_devices = [
-            version
-            for version, devices in simulators.items()
-            if len(devices) == 0
+            version for version, devices in simulators.items() if len(devices) == 0
         ]
         for version in versions_with_no_devices:
             simulators.pop(version)
 
         return simulators
 
-    except subprocess.CalledProcessError:
-        raise BriefcaseCommandError(
-            "Unable to run xcrun simctl."
-        )
+    except CommandOutputParseError as e:
+        raise BriefcaseCommandError("Unable to parse output of xcrun simctl") from e
+    except subprocess.CalledProcessError as e:
+        raise BriefcaseCommandError("Unable to run xcrun simctl.") from e
 
 
 def get_device_state(command, udid):
-    """
-    Determine the state of an iOS simulator device.
+    """Determine the state of an iOS simulator device.
 
     :param command: The command that needs to know the simulator device state.
     :param udid: The UDID of the device to inspect
     :returns: The status of the device, as a DeviceState enum.
     """
     try:
-        simctl_data = json.loads(
-            command.subprocess.check_output(
-                ['xcrun', 'simctl', 'list', 'devices', '-j', udid],
-                universal_newlines=True
-            )
+        simctl_data = command.subprocess.parse_output(
+            json_parser,
+            ["xcrun", "simctl", "list", "devices", "-j", udid],
         )
 
-        for runtime, devices in simctl_data['devices'].items():
+        for runtime, devices in simctl_data["devices"].items():
             for device in devices:
-                if device['udid'] == udid:
+                if device["udid"] == udid:
                     return {
-                        'Booted': DeviceState.BOOTED,
-                        'Shutting Down': DeviceState.SHUTTING_DOWN,
-                        'Shutdown': DeviceState.SHUTDOWN,
-                    }.get(device['state'], DeviceState.UNKNOWN)
+                        "Booted": DeviceState.BOOTED,
+                        "Shutting Down": DeviceState.SHUTTING_DOWN,
+                        "Shutdown": DeviceState.SHUTDOWN,
+                    }.get(device["state"], DeviceState.UNKNOWN)
 
         # If we fall out the bottom of the loop, the UDID didn't match
         # so we raise an error.
-        raise BriefcaseCommandError(
-            "Unable to determine status of device {udid}.".format(
-                udid=udid
-            )
-        )
-    except subprocess.CalledProcessError:
-        raise BriefcaseCommandError(
-            "Unable to run xcrun simctl."
-        )
+        raise BriefcaseCommandError(f"Unable to determine status of device {udid}.")
+    except CommandOutputParseError as e:
+        raise BriefcaseCommandError("Unable to parse output of xcrun simctl") from e
+    except subprocess.CalledProcessError as e:
+        raise BriefcaseCommandError("Unable to run xcrun simctl.") from e
 
 
 # A regex pattern that matches the content returned by `security find-identity`
-IDENTITY_RE = re.compile(r'\s*\d+\) ([0-9A-F]{40}) \"(.*)\"')
+IDENTITY_RE = re.compile(r"\s*\d+\) ([0-9A-F]{40}) \"(.*)\"")
 
 
 def get_identities(command, policy):
-    """
-    Obtain a set of valid identities for the given policy
+    """Obtain a set of valid identities for the given policy.
 
     :param command: The command that needs the identities.
     :param policy: The identity policy to evaluate (e.g., ``codesigning``)
     """
     try:
         output = command.subprocess.check_output(
-            ['security', 'find-identity', '-v', '-p', policy],
-            universal_newlines=True
+            ["security", "find-identity", "-v", "-p", policy],
         )
 
-        identities = dict(
+        return dict(
             IDENTITY_RE.match(line).groups()
-            for line in output.split('\n')
+            for line in output.split("\n")
             if IDENTITY_RE.match(line)
         )
 
-        return identities
-    except subprocess.CalledProcessError:
-        raise BriefcaseCommandError(
-            "Unable to run xcrun simctl."
-        )
+    except subprocess.CalledProcessError as e:
+        raise BriefcaseCommandError("Unable to run security find-identity.") from e
