@@ -4,8 +4,7 @@ import pkg_resources
 def get_platforms():
     return {
         entry_point.name: entry_point.load()
-        for entry_point
-        in pkg_resources.iter_entry_points('briefcase.platforms')
+        for entry_point in pkg_resources.iter_entry_points("briefcase.platforms")
     }
 
 
@@ -15,8 +14,7 @@ def get_output_formats(platform):
     # actual entry point names preserve case.
     return {
         entry_point.name: entry_point.load()
-        for entry_point
-        in pkg_resources.iter_entry_points('briefcase.formats.{platform}'.format(
-            platform=platform.lower()
-        ))
+        for entry_point in pkg_resources.iter_entry_points(
+            f"briefcase.formats.{platform.lower()}"
+        )
     }
