@@ -6,8 +6,8 @@ from briefcase.exceptions import BriefcaseCommandError
 
 
 class DummyDevCommand(DevCommand):
-    """
-    A dummy Dev command that doesn't actually do anything.
+    """A dummy Dev command that doesn't actually do anything.
+
     It only serves to track which actions would be performend.
     """
 
@@ -23,7 +23,7 @@ class DummyDevCommand(DevCommand):
 
     def verify_tools(self):
         super().verify_tools()
-        self.actions.append(('verify',))
+        self.actions.append(("verify",))
 
     def install_dev_dependencies(self, app, **kwargs):
         self.actions.append(("dev_dependencies", app.app_name, kwargs))
@@ -42,7 +42,7 @@ def dev_command(tmp_path):
 
 
 def test_no_args_one_app(dev_command, first_app):
-    "If there is one app, dev starts that app by default"
+    """If there is one app, dev starts that app by default."""
     # Add a single app
     dev_command.apps = {
         "first": first_app,
@@ -57,15 +57,14 @@ def test_no_args_one_app(dev_command, first_app):
     # The right sequence of things will be done
     assert dev_command.actions == [
         # Tools are verified
-        ('verify', ),
-
+        ("verify",),
         # Run the first app devly
         ("run_dev", "first", {}, dev_command.env),
     ]
 
 
 def test_no_args_two_apps(dev_command, first_app, second_app):
-    "If there are one app, dev starts that app by default"
+    """If there are one app, dev starts that app by default."""
     # Add two apps
     dev_command.apps = {
         "first": first_app,
@@ -82,12 +81,12 @@ def test_no_args_two_apps(dev_command, first_app, second_app):
     # No apps will be launched
     assert dev_command.actions == [
         # Tools are verified
-        ('verify', ),
+        ("verify",),
     ]
 
 
 def test_with_arg_one_app(dev_command, first_app):
-    "If there is one app, and a -a argument, dev starts that app"
+    """If there is one app, and a -a argument, dev starts that app."""
     # Add a single app
     dev_command.apps = {
         "first": first_app,
@@ -102,15 +101,14 @@ def test_with_arg_one_app(dev_command, first_app):
     # The right sequence of things will be done
     assert dev_command.actions == [
         # Tools are verified
-        ('verify', ),
-
+        ("verify",),
         # Run the first app devly
         ("run_dev", "first", {}, dev_command.env),
     ]
 
 
 def test_with_arg_two_apps(dev_command, first_app, second_app):
-    "If there are multiple apps, the --app argument starts app nominated"
+    """If there are multiple apps, the --app argument starts app nominated."""
     # Add two apps
     dev_command.apps = {
         "first": first_app,
@@ -126,15 +124,15 @@ def test_with_arg_two_apps(dev_command, first_app, second_app):
     # The right sequence of things will be done
     assert dev_command.actions == [
         # Tools are verified
-        ('verify', ),
-
+        ("verify",),
         # Run the second app devly
         ("run_dev", "second", {}, dev_command.env),
     ]
 
 
 def test_bad_app_reference(dev_command, first_app, second_app):
-    "If the command line argument refers to an app that doesn't exist, raise an error"
+    """If the command line argument refers to an app that doesn't exist, raise
+    an error."""
     # Add two apps
     dev_command.apps = {
         "first": first_app,
@@ -151,12 +149,12 @@ def test_bad_app_reference(dev_command, first_app, second_app):
     # No apps will be launched
     assert dev_command.actions == [
         # Tools are verified
-        ('verify', ),
+        ("verify",),
     ]
 
 
 def test_update_dependencies(dev_command, first_app):
-    "The dev command can request that the app is updated first"
+    """The dev command can request that the app is updated first."""
     # Add a single app
     dev_command.apps = {
         "first": first_app,
@@ -171,18 +169,16 @@ def test_update_dependencies(dev_command, first_app):
     # The right sequence of things will be done
     assert dev_command.actions == [
         # Tools are verified
-        ('verify', ),
-
+        ("verify",),
         # An update was requested
         ("dev_dependencies", "first", {}),
-
         # Then, it will be started
         ("run_dev", "first", {}, dev_command.env),
     ]
 
 
 def test_run_uninstalled(dev_command, first_app_uninstalled):
-    "The dev command will install first if the app hasn't been installed"
+    """The dev command will install first if the app hasn't been installed."""
     # Add a single app
     dev_command.apps = {
         "first": first_app_uninstalled,
@@ -197,18 +193,17 @@ def test_run_uninstalled(dev_command, first_app_uninstalled):
     # The right sequence of things will be done
     assert dev_command.actions == [
         # Tools are verified
-        ('verify', ),
-
+        ("verify",),
         # The app will be installed
         ("dev_dependencies", "first", {}),
-
         # Then, it will be started
         ("run_dev", "first", {}, dev_command.env),
     ]
 
 
 def test_update_uninstalled(dev_command, first_app_uninstalled):
-    "A request to update dependencies is redundant if the app hasn't been installed"
+    """A request to update dependencies is redundant if the app hasn't been
+    installed."""
     # Add a single app
     dev_command.apps = {
         "first": first_app_uninstalled,
@@ -223,18 +218,16 @@ def test_update_uninstalled(dev_command, first_app_uninstalled):
     # The right sequence of things will be done
     assert dev_command.actions == [
         # Tools are verified
-        ('verify', ),
-
+        ("verify",),
         # An update was requested
         ("dev_dependencies", "first", {}),
-
         # Then, it will be started
         ("run_dev", "first", {}, dev_command.env),
     ]
 
 
 def test_no_run(dev_command, first_app_uninstalled):
-    "Install dependencies without running the app"
+    """Install dependencies without running the app."""
     # Add a single app
     dev_command.apps = {
         "first": first_app_uninstalled,
@@ -249,8 +242,7 @@ def test_no_run(dev_command, first_app_uninstalled):
     # The right sequence of things will be done
     assert dev_command.actions == [
         # Tools are verified
-        ('verify', ),
-
+        ("verify",),
         # Only update dependencies without running the app
         ("dev_dependencies", "first", {}),
     ]
