@@ -5,24 +5,24 @@ from briefcase.exceptions import BriefcaseConfigError
 
 
 def test_minimal_AppConfig():
-    "A simple config can be defined"
+    """A simple config can be defined."""
     config = AppConfig(
         app_name="myapp",
         version="1.2.3",
         bundle="org.beeware",
         description="A simple app",
-        sources=['src/myapp', 'somewhere/else/interesting'],
+        sources=["src/myapp", "somewhere/else/interesting"],
     )
 
     # The basic properties have been set.
     assert config.app_name == "myapp"
-    assert config.version == '1.2.3'
-    assert config.bundle == 'org.beeware'
-    assert config.description == 'A simple app'
+    assert config.version == "1.2.3"
+    assert config.bundle == "org.beeware"
+    assert config.description == "A simple app"
     assert config.requires is None
 
     # Derived properties have been set.
-    assert config.formal_name == 'myapp'
+    assert config.formal_name == "myapp"
     assert config.document_types == {}
 
     # There is no icon or splash of any kind
@@ -30,27 +30,27 @@ def test_minimal_AppConfig():
     assert config.splash is None
 
     # The PYTHONPATH is derived correctly
-    assert config.PYTHONPATH == ['src', 'somewhere/else']
+    assert config.PYTHONPATH == ["src", "somewhere/else"]
 
     # The object has a meaningful REPL
     assert repr(config) == "<org.beeware.myapp v1.2.3 AppConfig>"
 
 
 def test_extra_attrs():
-    "A config can contain attributes in addition to those required"
+    """A config can contain attributes in addition to those required."""
     config = AppConfig(
         app_name="myapp",
         formal_name="My App",
         version="1.2.3",
         bundle="org.beeware",
         description="A simple app",
-        template='/path/to/template',
-        sources=['src/myapp'],
-        requires=['first', 'second', 'third'],
+        template="/path/to/template",
+        sources=["src/myapp"],
+        requires=["first", "second", "third"],
         document_type={
-            'document': {
-                'extension': 'doc',
-                'description': 'A document',
+            "document": {
+                "extension": "doc",
+                "description": "A document",
             }
         },
         first="value 1",
@@ -59,18 +59,18 @@ def test_extra_attrs():
 
     # The basic properties have been set.
     assert config.app_name == "myapp"
-    assert config.version == '1.2.3'
-    assert config.bundle == 'org.beeware'
-    assert config.description == 'A simple app'
-    assert config.template == '/path/to/template'
-    assert config.requires == ['first', 'second', 'third']
+    assert config.version == "1.2.3"
+    assert config.bundle == "org.beeware"
+    assert config.description == "A simple app"
+    assert config.template == "/path/to/template"
+    assert config.requires == ["first", "second", "third"]
 
     # Properties that are derived by default have been set explicitly
-    assert config.formal_name == 'My App'
+    assert config.formal_name == "My App"
     assert config.document_types == {
-        'document': {
-            'extension': 'doc',
-            'description': 'A document',
+        "document": {
+            "extension": "doc",
+            "description": "A document",
         }
     }
 
@@ -84,17 +84,17 @@ def test_extra_attrs():
 
 
 @pytest.mark.parametrize(
-    'name',
+    "name",
     [
-        'myapp',  # lowercase
-        'myApp',  # contains uppercase
-        'MyApp',  # initial uppercase
-        'MyAPP',  # ends in uppercase
-        'my-app',  # contains hyphen
-        'my_app',  # contains underscore
-        'myapp2',  # ends with digit
-        'my2app',  # contains digit
-    ]
+        "myapp",  # lowercase
+        "myApp",  # contains uppercase
+        "MyApp",  # initial uppercase
+        "MyAPP",  # ends in uppercase
+        "my-app",  # contains hyphen
+        "my_app",  # contains underscore
+        "myapp2",  # ends with digit
+        "my2app",  # contains digit
+    ],
 )
 def test_valid_app_name(name):
     try:
@@ -103,24 +103,24 @@ def test_valid_app_name(name):
             version="1.2.3",
             bundle="org.beeware",
             description="A simple app",
-            sources=['src/' + name.replace('-', '_')]
+            sources=["src/" + name.replace("-", "_")],
         )
     except BriefcaseConfigError:
-        pytest.fail('{name} should be valid'.format(name=name))
+        pytest.fail(f"{name} should be valid")
 
 
 @pytest.mark.parametrize(
-    'name',
+    "name",
     [
-        '!myapp',  # initial punctuation
-        'my!app',  # contains punctuation
-        'myapp!',  # end punctuation
-        'my$app',  # other punctuation
-        '-myApp',  # initial hyphen
-        'myApp-',  # end hyphen
-        '_myApp',  # initial underscore
-        'myApp_',  # end underscore
-    ]
+        "!myapp",  # initial punctuation
+        "my!app",  # contains punctuation
+        "myapp!",  # end punctuation
+        "my$app",  # other punctuation
+        "-myApp",  # initial hyphen
+        "myApp-",  # end hyphen
+        "_myApp",  # initial underscore
+        "myApp_",  # end underscore
+    ],
 )
 def test_invalid_app_name(name):
     with pytest.raises(BriefcaseConfigError, match=r"is not a valid app name\."):
@@ -129,7 +129,56 @@ def test_invalid_app_name(name):
             version="1.2.3",
             bundle="org.beeware",
             description="A simple app",
-            sources=['src/invalid']
+            sources=["src/invalid"],
+        )
+
+
+@pytest.mark.parametrize(
+    "bundle",
+    [
+        "com.example",
+        "com.example.more",
+        "com.example42.more",
+        "com.example-42.more",
+    ],
+)
+def test_valid_bundle(bundle):
+    try:
+        AppConfig(
+            app_name="myapp",
+            version="1.2.3",
+            bundle=bundle,
+            description="A simple app",
+            sources=["src/myapp"],
+        )
+    except BriefcaseConfigError:
+        pytest.fail(f"{bundle} should be valid")
+
+
+@pytest.mark.parametrize(
+    "bundle",
+    [
+        "not a bundle!",  # Free text.
+        "home",  # Only one section.
+        "com.hello_world",  # underscore
+        "com.hello,world",  # comma
+        "com.hello world!",  # exclamation point
+        "com.pass",  # Python reserved word
+        "com.pass.example",  # Python reserved word
+        "com.switch",  # Java reserved word
+        "com.switch.example",  # Java reserved word
+    ],
+)
+def test_invalid_bundle_identifier(bundle):
+    with pytest.raises(
+        BriefcaseConfigError, match=r"is not a valid bundle identifier\."
+    ):
+        AppConfig(
+            app_name="myapp",
+            version="1.2.3",
+            bundle=bundle,
+            description="A simple app",
+            sources=["src/invalid"],
         )
 
 
@@ -140,29 +189,32 @@ def test_valid_app_version():
             version="1.2.3",
             bundle="org.beeware",
             description="A simple app",
-            sources=['src/myapp']
+            sources=["src/myapp"],
         )
     except BriefcaseConfigError:
-        pytest.fail('1.2.3 should be a valid version number')
+        pytest.fail("1.2.3 should be a valid version number")
 
 
 def test_invalid_app_version():
-    with pytest.raises(BriefcaseConfigError, match=r"Version number for myapp.*is not valid\."):
+    with pytest.raises(
+        BriefcaseConfigError,
+        match=r"Version number for 'myapp' \(foobar\) is not valid\.",
+    ):
         AppConfig(
             app_name="myapp",
             version="foobar",
             bundle="org.beeware",
             description="A simple app",
-            sources=['src/invalid']
+            sources=["src/invalid"],
         )
 
 
 @pytest.mark.parametrize(
-    'name, module_name',
+    "name, module_name",
     [
-        ('myapp', 'myapp'),
-        ('my-app', 'my_app'),
-    ]
+        ("myapp", "myapp"),
+        ("my-app", "my_app"),
+    ],
 )
 def test_module_name(name, module_name):
     config = AppConfig(
@@ -170,18 +222,18 @@ def test_module_name(name, module_name):
         version="1.2.3",
         bundle="org.beeware",
         description="A simple app",
-        sources=['src/' + module_name]
+        sources=["src/" + module_name],
     )
 
     assert config.module_name == module_name
 
 
 @pytest.mark.parametrize(
-    'bundle, package_name',
+    "bundle, package_name",
     [
-        ('com.example', 'com.example'),
-        ('com.ex-ample', 'com.ex_ample'),
-    ]
+        ("com.example", "com.example"),
+        ("com.ex-ample", "com.ex_ample"),
+    ],
 )
 def test_package_name(bundle, package_name):
     config = AppConfig(
@@ -189,38 +241,42 @@ def test_package_name(bundle, package_name):
         version="1.2.3",
         bundle=bundle,
         description="A simple app",
-        sources=['src/myapp']
+        sources=["src/myapp"],
     )
 
     assert config.package_name == package_name
 
 
 @pytest.mark.parametrize(
-    'sources',
+    "sources",
     [
-        ['src/dupe', 'src/dupe'],
-        ['src/dupe', 'src/other', 'src/dupe'],
-        ['src/dupe', 'somewhere/dupe', 'src/other'],
-        ['src/dupe', 'src/deep/dupe', 'src/other'],
-    ]
+        ["src/dupe", "src/dupe"],
+        ["src/dupe", "src/other", "src/dupe"],
+        ["src/dupe", "somewhere/dupe", "src/other"],
+        ["src/dupe", "src/deep/dupe", "src/other"],
+    ],
 )
 def test_duplicated_source(sources):
-    with pytest.raises(BriefcaseConfigError, match=r"contains duplicated package names\."):
+    with pytest.raises(
+        BriefcaseConfigError, match=r"contains duplicated package names\."
+    ):
         AppConfig(
-            app_name='dupe',
+            app_name="dupe",
             version="1.2.3",
             bundle="org.beeware",
             description="A simple app",
-            sources=sources
+            sources=sources,
         )
 
 
 def test_no_source_for_app():
-    with pytest.raises(BriefcaseConfigError, match=r" does not include a package named 'my_app'\."):
+    with pytest.raises(
+        BriefcaseConfigError, match=r" does not include a package named 'my_app'\."
+    ):
         AppConfig(
-            app_name='my-app',
+            app_name="my-app",
             version="1.2.3",
             bundle="org.beeware",
             description="A simple app",
-            sources=['src/something', 'src/other']
+            sources=["src/something", "src/other"],
         )
