@@ -1,4 +1,4 @@
-from io import StringIO
+from io import BytesIO
 
 import pytest
 
@@ -7,17 +7,18 @@ from briefcase.exceptions import BriefcaseConfigError
 
 
 def test_invalid_toml():
-    "If the config file isn't TOML, raise an error"
-    config_file = StringIO("this is not toml!")
+    """If the config file isn't TOML, raise an error."""
+    config_file = BytesIO(b"this is not toml!")
 
     with pytest.raises(BriefcaseConfigError, match="Invalid pyproject.toml"):
-        parse_config(config_file, platform='macOS', output_format='xcode')
+        parse_config(config_file, platform="macOS", output_format="xcode")
 
 
 def test_no_briefcase_section():
-    "If the config file doesn't contain a briefcase tool section, raise an error"
-    config_file = StringIO(
-        """
+    """If the config file doesn't contain a briefcase tool section, raise an
+    error."""
+    config_file = BytesIO(
+        b"""
         [tool.section]
         name="value"
         number=42
@@ -25,13 +26,14 @@ def test_no_briefcase_section():
     )
 
     with pytest.raises(BriefcaseConfigError, match="No tool.briefcase section"):
-        parse_config(config_file, platform='macOS', output_format='xcode')
+        parse_config(config_file, platform="macOS", output_format="xcode")
 
 
 def test_no_apps():
-    "If the config file doesn't contain at least one briefcase app, raise an error"
-    config_file = StringIO(
-        """
+    """If the config file doesn't contain at least one briefcase app, raise an
+    error."""
+    config_file = BytesIO(
+        b"""
         [tool.briefcase]
         name="value"
         number=42
@@ -39,13 +41,14 @@ def test_no_apps():
     )
 
     with pytest.raises(BriefcaseConfigError, match="No Briefcase apps defined"):
-        parse_config(config_file, platform='macOS', output_format='xcode')
+        parse_config(config_file, platform="macOS", output_format="xcode")
 
 
 def test_single_minimal_app():
-    "A single app can be defined, but can exist without any app attributes"
-    config_file = StringIO(
-        """
+    """A single app can be defined, but can exist without any app
+    attributes."""
+    config_file = BytesIO(
+        b"""
         [tool.briefcase]
         value = 42
 
@@ -53,27 +56,23 @@ def test_single_minimal_app():
         """
     )
 
-    global_options, apps = parse_config(config_file, platform='macOS', output_format='xcode')
+    global_options, apps = parse_config(
+        config_file, platform="macOS", output_format="xcode"
+    )
 
     # There's a single global option
-    assert global_options == {
-        'value': 42
-    }
+    assert global_options == {"value": 42}
 
     # The app gets the name from it's header line.
     # It inherits the value from the base definition.
-    assert apps == {
-        'my_app': {
-            "app_name": "my_app",
-            "value": 42
-        }
-    }
+    assert apps == {"my_app": {"app_name": "my_app", "value": 42}}
 
 
 def test_multiple_minimal_apps():
-    "The configuration can contain multiple apps without an explicit tool header"
-    config_file = StringIO(
-        """
+    """The configuration can contain multiple apps without an explicit tool
+    header."""
+    config_file = BytesIO(
+        b"""
         [tool.briefcase.app.first]
         number=37
 
@@ -83,7 +82,9 @@ def test_multiple_minimal_apps():
         """
     )
 
-    global_options, apps = parse_config(config_file, platform='macOS', output_format='xcode')
+    global_options, apps = parse_config(
+        config_file, platform="macOS", output_format="xcode"
+    )
 
     # There are no global options
     assert global_options == {}
@@ -91,11 +92,11 @@ def test_multiple_minimal_apps():
     # The apps gets their name from the header lines.
     # The second tool overrides it's app name
     assert apps == {
-        'first': {
+        "first": {
             "app_name": "first",
             "number": 37,
         },
-        'second': {
+        "second": {
             "app_name": "my_app",
             "number": 42,
         },
@@ -103,9 +104,9 @@ def test_multiple_minimal_apps():
 
 
 def test_platform_override():
-    "An app can define platform settings that override base settings"
-    config_file = StringIO(
-        """
+    """An app can define platform settings that override base settings."""
+    config_file = BytesIO(
+        b"""
         [tool.briefcase]
         value = 0
         basevalue = "the base"
@@ -128,12 +129,14 @@ def test_platform_override():
         """
     )
 
-    global_options, apps = parse_config(config_file, platform='macOS', output_format='xcode')
+    global_options, apps = parse_config(
+        config_file, platform="macOS", output_format="xcode"
+    )
 
     # The global options are exactly as specified
     assert global_options == {
-        'value': 0,
-        'basevalue': 'the base',
+        "value": 0,
+        "basevalue": "the base",
     }
 
     # Since a macOS app has been requested, the macOS platform values
@@ -143,26 +146,26 @@ def test_platform_override():
     # Platforms should be processed in sorted order, which means that linux
     # will be processed before macos.
     assert apps == {
-        'my_app': {
+        "my_app": {
             "app_name": "my_app",
             "value": 2,
             "basevalue": "the base",
             "appvalue": "the app",
             "platformvalue": "macos platform",
         },
-        'other_app': {
+        "other_app": {
             "app_name": "other_app",
             "value": 4,
             "basevalue": "the base",
             "platformvalue": "other macos platform",
-        }
+        },
     }
 
 
 def test_platform_override_ordering():
-    "The order of platform processing doesn't affect output"
-    config_file = StringIO(
-        """
+    """The order of platform processing doesn't affect output."""
+    config_file = BytesIO(
+        b"""
         [tool.briefcase]
         value = 0
         basevalue = "the base"
@@ -185,13 +188,12 @@ def test_platform_override_ordering():
         """
     )
 
-    global_options, apps = parse_config(config_file, platform='macOS', output_format='xcode')
+    global_options, apps = parse_config(
+        config_file, platform="macOS", output_format="xcode"
+    )
 
     # The global options are exactly as specified
-    assert global_options == {
-        'value': 0,
-        'basevalue': "the base"
-    }
+    assert global_options == {"value": 0, "basevalue": "the base"}
 
     # Since a macOS app has been requested, the macOS platform values
     # take priority. Linux configuration values are dropped.
@@ -200,26 +202,27 @@ def test_platform_override_ordering():
     # Platforms should be processed in order, which means that windows
     # will be processed after macos.
     assert apps == {
-        'my_app': {
+        "my_app": {
             "app_name": "my_app",
             "value": 2,
             "basevalue": "the base",
             "appvalue": "the app",
             "platformvalue": "macos platform",
         },
-        'other_app': {
+        "other_app": {
             "app_name": "other_app",
             "value": 4,
             "basevalue": "the base",
             "platformvalue": "other macos platform",
-        }
+        },
     }
 
 
 def test_format_override():
-    "An app can define format settings that override base and platform settings"
-    config_file = StringIO(
-        """
+    """An app can define format settings that override base and platform
+    settings."""
+    config_file = BytesIO(
+        b"""
         [tool.briefcase]
         value = 0
         basevalue = "the base"
@@ -262,13 +265,12 @@ def test_format_override():
         """
     )
 
-    global_options, apps = parse_config(config_file, platform='macOS', output_format='app')
+    global_options, apps = parse_config(
+        config_file, platform="macOS", output_format="app"
+    )
 
     # The global options are exactly as specified
-    assert global_options == {
-        'value': 0,
-        'basevalue': "the base"
-    }
+    assert global_options == {"value": 0, "basevalue": "the base"}
 
     # Since a macOS app has been requested, the macOS app format values
     # take priority. Linux configuration values are dropped.
@@ -277,7 +279,7 @@ def test_format_override():
     # Formats should be processed in order, which means that app
     # will be processed before dmg and homebrew.
     assert apps == {
-        'my_app': {
+        "my_app": {
             "app_name": "my_app",
             "value": 21,
             "basevalue": "the base",
@@ -285,19 +287,19 @@ def test_format_override():
             "platformvalue": "macos platform",
             "formatvalue": "app format",
         },
-        'other_app': {
+        "other_app": {
             "app_name": "other_app",
             "value": 41,
             "basevalue": "the base",
             "formatvalue": "other macos app format",
-        }
+        },
     }
 
 
 def test_format_override_ordering():
-    "The order of format processing doesn't affect output"
-    config_file = StringIO(
-        """
+    """The order of format processing doesn't affect output."""
+    config_file = BytesIO(
+        b"""
         [tool.briefcase]
         value = 0
         basevalue = "the base"
@@ -340,13 +342,12 @@ def test_format_override_ordering():
         """
     )
 
-    global_options, apps = parse_config(config_file, platform='macOS', output_format='app')
+    global_options, apps = parse_config(
+        config_file, platform="macOS", output_format="app"
+    )
 
     # The global options are exactly as specified
-    assert global_options == {
-        'value': 0,
-        'basevalue': "the base"
-    }
+    assert global_options == {"value": 0, "basevalue": "the base"}
 
     # Since a macOS dmg has been requested, the macOS dmg format values
     # take priority. Linux configuration values are dropped.
@@ -355,7 +356,7 @@ def test_format_override_ordering():
     # Formats should be processed in order, which means that dmg
     # will be processed after app, but before homebrew.
     assert apps == {
-        'my_app': {
+        "my_app": {
             "app_name": "my_app",
             "value": 22,
             "basevalue": "the base",
@@ -363,18 +364,18 @@ def test_format_override_ordering():
             "platformvalue": "macos platform",
             "formatvalue": "app format",
         },
-        'other_app': {
+        "other_app": {
             "app_name": "other_app",
             "value": 0,
             "basevalue": "the base",
-        }
+        },
     }
 
 
 def test_requires():
-    "Requirements can be specified"
-    config_file = StringIO(
-        """
+    """Requirements can be specified."""
+    config_file = BytesIO(
+        b"""
         [tool.briefcase]
         value = 0
         requires = ["base value"]
@@ -402,18 +403,20 @@ def test_requires():
     )
 
     # Request a macOS app
-    global_options, apps = parse_config(config_file, platform='macOS', output_format='app')
+    global_options, apps = parse_config(
+        config_file, platform="macOS", output_format="app"
+    )
 
     # The global options are exactly as specified
     assert global_options == {
-        'value': 0,
-        'requires': ["base value"],
+        "value": 0,
+        "requires": ["base value"],
     }
 
     # The macOS my_app app specifies a full inherited chain.
     # The other_app app doesn't specify any options.
     assert apps == {
-        'my_app': {
+        "my_app": {
             "app_name": "my_app",
             "requires": [
                 "base value",
@@ -423,29 +426,28 @@ def test_requires():
             ],
             "value": 0,
         },
-        'other_app': {
+        "other_app": {
             "app_name": "other_app",
             "requires": [
                 "base value",
             ],
             "value": 0,
-        }
+        },
     }
 
     # Request a macOS xcode project
     config_file.seek(0)
-    global_options, apps = parse_config(config_file, platform='macOS', output_format='xcode')
+    global_options, apps = parse_config(
+        config_file, platform="macOS", output_format="xcode"
+    )
 
     # The global options are exactly as specified
-    assert global_options == {
-        'value': 0,
-        'requires': ["base value"]
-    }
+    assert global_options == {"value": 0, "requires": ["base value"]}
 
     # The macOS my_app dmg specifies a full inherited chain.
     # The other_app dmg doesn't specify any options.
     assert apps == {
-        'my_app': {
+        "my_app": {
             "app_name": "my_app",
             "requires": [
                 "base value",
@@ -455,27 +457,26 @@ def test_requires():
             ],
             "value": 0,
         },
-        'other_app': {
+        "other_app": {
             "app_name": "other_app",
             "requires": [
                 "base value",
             ],
             "value": 0,
-        }
+        },
     }
 
     config_file.seek(0)
-    global_options, apps = parse_config(config_file, platform='linux', output_format='appimage')
+    global_options, apps = parse_config(
+        config_file, platform="linux", output_format="appimage"
+    )
 
     # The global options are exactly as specified
-    assert global_options == {
-        'value': 0,
-        'requires': ["base value"]
-    }
+    assert global_options == {"value": 0, "requires": ["base value"]}
 
     # The linux my_app appimage overrides the *base* value, but extends for linux.
     assert apps == {
-        'my_app': {
+        "my_app": {
             "app_name": "my_app",
             "requires": [
                 "base value",
@@ -485,20 +486,20 @@ def test_requires():
             ],
             "value": 0,
         },
-        'other_app': {
+        "other_app": {
             "app_name": "other_app",
             "requires": [
                 "base value",
             ],
             "value": 0,
-        }
+        },
     }
 
 
 def test_document_types():
-    "Document types can be specified"
-    config_file = StringIO(
-        """
+    """Document types can be specified."""
+    config_file = BytesIO(
+        b"""
         [tool.briefcase]
         value = 0
 
@@ -520,27 +521,29 @@ def test_document_types():
     )
 
     # Request a macOS app
-    global_options, apps = parse_config(config_file, platform='macOS', output_format='xcode')
+    global_options, apps = parse_config(
+        config_file, platform="macOS", output_format="xcode"
+    )
 
     # The macOS my_app app specifies a full inherited chain.
     # The other_app app doesn't specify any options.
     assert apps == {
-        'my_app': {
+        "my_app": {
             "app_name": "my_app",
             "document_type": {
-                'document': {
-                    'extension': 'doc',
-                    'description': 'A document',
+                "document": {
+                    "extension": "doc",
+                    "description": "A document",
+                },
+                "image": {
+                    "extension": "img",
+                    "description": "An image",
                 },
-                'image': {
-                    'extension': 'img',
-                    'description': 'An image',
-                }
             },
             "value": 0,
         },
-        'other_app': {
+        "other_app": {
             "app_name": "other_app",
             "value": 0,
-        }
+        },
     }
