@@ -4,7 +4,7 @@ from briefcase.integrations.linuxdeploy import LinuxDeploy
 
 
 def test_managed_install():
-    "All linuxdeploy installs are managed"
+    """All linuxdeploy installs are managed."""
     linuxdeploy = LinuxDeploy(MagicMock())
 
     assert linuxdeploy.managed_install
