@@ -6,7 +6,13 @@ def test_binary_path(first_app_config, tmp_path):
     binary_path = command.binary_path(first_app_config)
 
     assert binary_path == (
-        tmp_path / 'iOS' / 'Xcode' / 'First App' / 'build' / 'Debug-iphonesimulator' / 'First App.app'
+        tmp_path
+        / "iOS"
+        / "Xcode"
+        / "First App"
+        / "build"
+        / "Debug-iphonesimulator"
+        / "First App.app"
     )
 
 
@@ -15,5 +21,11 @@ def test_distribution_path(first_app_config, tmp_path):
     binary_path = command.binary_path(first_app_config)
 
     assert binary_path == (
-        tmp_path / 'iOS' / 'Xcode' / 'First App' / 'build' / 'Debug-iphonesimulator' / 'First App.app'
+        tmp_path
+        / "iOS"
+        / "Xcode"
+        / "First App"
+        / "build"
+        / "Debug-iphonesimulator"
+        / "First App.app"
     )
