@@ -12,19 +12,19 @@ from briefcase.platforms.linux.appimage import LinuxAppImageCreateCommand
 def test_binary_path(first_app_config, tmp_path):
     command = LinuxAppImageCreateCommand(base_path=tmp_path)
     # Force the architecture to x86_64 for test purposes.
-    command.host_arch = 'x86_64'
+    command.host_arch = "x86_64"
     binary_path = command.binary_path(first_app_config)
 
-    assert binary_path == tmp_path / 'linux' / 'First_App-0.0.1-x86_64.AppImage'
+    assert binary_path == tmp_path / "linux" / "First_App-0.0.1-x86_64.AppImage"
 
 
 def test_distribution_path(first_app_config, tmp_path):
     command = LinuxAppImageCreateCommand(base_path=tmp_path)
     # Force the architecture to x86_64 for test purposes.
-    command.host_arch = 'x86_64'
-    distribution_path = command.distribution_path(first_app_config, 'appimage')
+    command.host_arch = "x86_64"
+    distribution_path = command.distribution_path(first_app_config, "appimage")
 
-    assert distribution_path == tmp_path / 'linux' / 'First_App-0.0.1-x86_64.AppImage'
+    assert distribution_path == tmp_path / "linux" / "First_App-0.0.1-x86_64.AppImage"
 
 
 def test_docker_image_tag(first_app_config, tmp_path):
@@ -32,9 +32,7 @@ def test_docker_image_tag(first_app_config, tmp_path):
 
     image_tag = command.docker_image_tag(first_app_config)
 
-    assert image_tag == 'briefcase/com.example.first-app:py3.{minor}'.format(
-        minor=sys.version_info.minor
-    )
+    assert image_tag == f"briefcase/com.example.first-app:py3.{sys.version_info.minor}"
 
 
 def test_docker_image_tag_uppercase_name(uppercase_app_config, tmp_path):
@@ -42,9 +40,7 @@ def test_docker_image_tag_uppercase_name(uppercase_app_config, tmp_path):
 
     image_tag = command.docker_image_tag(uppercase_app_config)
 
-    assert image_tag == 'briefcase/com.example.first-app:py3.{minor}'.format(
-        minor=sys.version_info.minor
-    )
+    assert image_tag == f"briefcase/com.example.first-app:py3.{sys.version_info.minor}"
 
 
 def test_dockerize(first_app_config, tmp_path):
@@ -64,7 +60,7 @@ def test_dockerize(first_app_config, tmp_path):
 
 
 def test_dockerize_nodocker(first_app_config, tmp_path):
-    "If docker is not in use, dockerize() is a no-op."
+    """If docker is not in use, dockerize() is a no-op."""
     command = LinuxAppImageCreateCommand(base_path=tmp_path)
     command.Docker = Docker
     command.use_docker = False
@@ -81,7 +77,7 @@ def test_dockerize_nodocker(first_app_config, tmp_path):
 
 
 def test_verify_linux_no_docker(tmp_path):
-    "If Docker is disabled on Linux, the Docker alias is not set"
+    """If Docker is disabled on Linux, the Docker alias is not set."""
     command = LinuxAppImageCreateCommand(base_path=tmp_path)
     command.host_os = "Linux"
     command.use_docker = False
@@ -94,11 +90,10 @@ def test_verify_linux_no_docker(tmp_path):
 
 
 def test_verify_non_linux_no_docker(tmp_path):
-    "If Docker is disabled on non-Linux, an error is raised"
+    """If Docker is disabled on non-Linux, an error is raised."""
     command = LinuxAppImageCreateCommand(base_path=tmp_path)
     command.host_os = "WeirdOS"
     command.use_docker = False
-    command.verbosity = 0
 
     # Verify the tools
     with pytest.raises(BriefcaseCommandError):
@@ -106,14 +101,15 @@ def test_verify_non_linux_no_docker(tmp_path):
 
 
 def test_verify_linux_docker(tmp_path):
-    "If Docker is enabled on Linux, the Docker alias is set"
+    """If Docker is enabled on Linux, the Docker alias is set."""
     command = LinuxAppImageCreateCommand(base_path=tmp_path)
     command.host_os = "Linux"
     command.use_docker = True
-    command.verbosity = 0
     # Mock the existence of Docker.
     command.subprocess = MagicMock()
-    command.subprocess.check_output.return_value = "Docker version 19.03.8, build afacb8b\n"
+    command.subprocess.check_output.return_value = (
+        "Docker version 19.03.8, build afacb8b\n"
+    )
 
     # Verify the tools
     command.verify_tools()
@@ -123,14 +119,15 @@ def test_verify_linux_docker(tmp_path):
 
 
 def test_verify_non_linux_docker(tmp_path):
-    "If Docker is enabled on non-Linux, the Docker alias is set"
+    """If Docker is enabled on non-Linux, the Docker alias is set."""
     command = LinuxAppImageCreateCommand(base_path=tmp_path)
     command.host_os = "WierdOS"
     command.use_docker = True
-    command.verbosity = 0
     # Mock the existence of Docker.
     command.subprocess = MagicMock()
-    command.subprocess.check_output.return_value = "Docker version 19.03.8, build afacb8b\n"
+    command.subprocess.check_output.return_value = (
+        "Docker version 19.03.8, build afacb8b\n"
+    )
 
     # Verify the tools
     command.verify_tools()
@@ -140,11 +137,10 @@ def test_verify_non_linux_docker(tmp_path):
 
 
 def test_verify_windows_docker(tmp_path):
-    "Docker cannot currently be used on Windows due to path issues"
+    """Docker cannot currently be used on Windows due to path issues."""
     command = LinuxAppImageCreateCommand(base_path=tmp_path)
     command.host_os = "Windows"
     command.use_docker = True
-    command.verbosity = 0
 
     # Verify the tools
     with pytest.raises(BriefcaseCommandError):
